
 ## pysong
 pysong is a library containing data structures for representing symbolic 
music scores. The package was created for use in algorithmic music generation,
so it focuses on simple representation for core music data such as pitches and
rhythm. Libraries are provided to import/export from MIDI.
